@@ -6,7 +6,7 @@ import logging
 
 
 _moduleLogger = logging.getLogger("dialcentral")
-sys.path.insert(0,"/usr/lib/dialcentral/")
+sys.path.insert(0,"/opt/dialcentral/lib")
 
 
 import constants
@@ -21,6 +21,9 @@ except OSError, e:
 
 logging.basicConfig(level=logging.DEBUG, filename=constants._user_logpath_)
 _moduleLogger.info("Dialcentral %s-%s" % (constants.__version__, constants.__build__))
+_moduleLogger.info("OS: %s" % (os.uname()[0], ))
+_moduleLogger.info("Kernel: %s (%s) for %s" % os.uname()[2:])
+_moduleLogger.info("Hostname: %s" % os.uname()[1])
 
 try:
 	dc_glade.run_dialpad()
